@@ -46,6 +46,7 @@ class WebOsClient:
         ping_timeout=20,
         client_key=None,
         volume_step_delay_ms=None,
+        get_hello_info=False,
         states=["system_info", "software_info", "power", "current_app", "muted",
                 "volume", "apps", "inputs", "sound_output", "picture_settings"],
         storage: StorageProto=None,
@@ -60,6 +61,7 @@ class WebOsClient:
         self.timeout_connect = timeout_connect
         self.ping_interval = ping_interval
         self.ping_timeout = ping_timeout
+        self.get_hello_info = get_hello_info
         self.storage = storage
         self.connect_task = None
         self.connect_result = None
@@ -79,6 +81,7 @@ class WebOsClient:
         self._extinputs = {}
         self._system_info = None
         self._software_info = None
+        self._hello_info = None
         self._sound_output = None
         self._picture_settings = None
         self.state_update_callbacks = []
@@ -151,6 +154,19 @@ class WebOsClient:
                 ),
                 timeout=self.timeout_connect,
             )
+
+            if self.get_hello_info:
+                # send hello
+                await ws.send(json.dumps({"id": "hello", "type": "hello"}))
+                raw_response = await ws.recv()
+                response = json.loads(raw_response)
+
+                if response["type"] == "hello":
+                    self._hello_info = response["payload"]
+                else:
+                    raise PyLGTVPairException("Unable to say hello")
+
+            # send registration
             await ws.send(json.dumps(self.registration_msg()))
             raw_response = await ws.recv()
             response = json.loads(raw_response)
@@ -265,6 +281,7 @@ class WebOsClient:
             self._extinputs = {}
             self._system_info = None
             self._software_info = None
+            self._hello_info = None
             self._sound_output = None
             self._picture_settings = None
 
@@ -293,6 +310,7 @@ class WebOsClient:
             asyncio.TimeoutError,
             asyncio.CancelledError,
             websockets.exceptions.ConnectionClosedError,
+            websockets.exceptions.ConnectionClosedOK,
         ):
             pass
 
@@ -330,7 +348,11 @@ class WebOsClient:
                     elif future is not None and not future.done():
                         self.futures[uid].set_result(msg)
 
-        except (websockets.exceptions.ConnectionClosedError, asyncio.CancelledError):
+        except (
+            asyncio.CancelledError,
+            websockets.exceptions.ConnectionClosedError,
+            websockets.exceptions.ConnectionClosedOK,
+        ):
             pass
         finally:
             for task in callback_tasks.values():
@@ -394,6 +416,10 @@ class WebOsClient:
     def software_info(self):
         return self._software_info
 
+    @property
+    def hello_info(self):
+        return self._hello_info
+
     @property
     def sound_output(self):
         return self._sound_output
@@ -657,9 +683,14 @@ class WebOsClient:
 
     # high level request handling
 
-    async def button(self, name):
+    async def button(self, name, checkValid=True):
         """Send button press command."""
 
+        if checkValid and str(name) not in btn.BUTTONS:
+            raise ValueError(
+                f"button {name} is not valid, use checkValid=False to try a new one"
+            )
+
         message = f"type:button\nname:{name}\n\n"
         await self.input_command(message)
 
@@ -766,6 +797,10 @@ class WebOsClient:
         """Return the system information."""
         return await self.request(ep.GET_SYSTEM_INFO)
 
+    async def get_hello_info(self):
+        """Return hello information."""
+        return self._hello_info
+
     async def power_off(self):
         """Power off TV."""
 
@@ -783,23 +818,27 @@ class WebOsClient:
         """Play media."""
         return await self.request(ep.POWER_ON)
 
-    async def turn_screen_off_wo4(self):
-        """Turn TV Screen off for WebOS v4.x.
-        standbyMode values: 'active' or 'passive', passive cannot turn screen back on, need to pull TV plug.
+    async def turn_screen_off(self, webos_ver=""):
+        """Turn TV Screen off. standbyMode values: 'active' or 'passive',
+        passive cannot turn screen back on, need to pull TV plug.
         """
-        return await self.request(ep.TURN_OFF_SCREEN_WO4, {"standbyMode": "active"})
+        epName = f"TURN_OFF_SCREEN_WO{webos_ver}" if webos_ver else "TURN_OFF_SCREEN"
 
-    async def turn_screen_on_wo4(self):
-        """Turn TV Screen on for WebOS v4.x."""
-        return await self.request(ep.TURN_ON_SCREEN_WO4, {"standbyMode": "active"})
+        if not hasattr(ep, epName):
+            raise ValueError(f"there's no {epName} endpoint")
 
-    async def turn_screen_off(self):
-        """Turn TV Screen off."""
-        return await self.request(ep.TURN_OFF_SCREEN, {"standbyMode": "active"})
+        return await self.request(getattr(ep, epName), {"standbyMode": "active"})
 
-    async def turn_screen_on(self):
-        """Turn TV Screen on."""
-        return await self.request(ep.TURN_ON_SCREEN, {"standbyMode": "active"})
+    async def turn_screen_on(self, webos_ver=""):
+        """Turn TV Screen on. standbyMode values: 'active' or 'passive',
+        passive cannot turn screen back on, need to pull TV plug.
+        """
+        epName = f"TURN_ON_SCREEN_WO{webos_ver}" if webos_ver else "TURN_ON_SCREEN"
+
+        if not hasattr(ep, epName):
+            raise ValueError(f"there's no {epName} endpoint")
+
+        return await self.request(getattr(ep, epName), {"standbyMode": "active"})
 
     # 3D Mode
     async def turn_3d_on(self):
@@ -1000,102 +1039,6 @@ class WebOsClient:
         """Close web app."""
         return await self.request(ep.CLOSE_WEB_APP)
 
-    # Emulated button presses
-    async def left_button(self):
-        """left button press."""
-        await self.button(btn.LEFT)
-
-    async def right_button(self):
-        """right button press."""
-        await self.button(btn.RIGHT)
-
-    async def down_button(self):
-        """down button press."""
-        await self.button(btn.DOWN)
-
-    async def up_button(self):
-        """up button press."""
-        await self.button(btn.UP)
-
-    async def home_button(self):
-        """home button press."""
-        await self.button(btn.HOME)
-
-    async def back_button(self):
-        """back button press."""
-        await self.button(btn.BACK)
-
-    async def ok_button(self):
-        """ok button press."""
-        await self.button(btn.ENTER)
-
-    async def dash_button(self):
-        """dash button press."""
-        await self.button(btn.DASH)
-
-    async def info_button(self):
-        """info button press."""
-        await self.button(btn.INFO)
-
-    async def asterisk_button(self):
-        """asterisk button press."""
-        await self.button(btn.ASTERISK)
-
-    async def cc_button(self):
-        """cc button press."""
-        await self.button(btn.CC)
-
-    async def exit_button(self):
-        """exit button press."""
-        await self.button(btn.EXIT)
-
-    async def mute_button(self):
-        """mute button press."""
-        await self.button(btn.MUTE)
-
-    async def red_button(self):
-        """red button press."""
-        await self.button(btn.RED)
-
-    async def green_button(self):
-        """green button press."""
-        await self.button(btn.GREEN)
-
-    async def blue_button(self):
-        """blue button press."""
-        await self.button(btn.BLUE)
-
-    async def volume_up_button(self):
-        """volume up button press."""
-        await self.button(btn.VOLUMEUP)
-
-    async def volume_down_button(self):
-        """volume down button press."""
-        await self.button(btn.VOLUMEDOWN)
-
-    async def channel_up_button(self):
-        """channel up button press."""
-        await self.button(btn.CHANNELUP)
-
-    async def channel_down_button(self):
-        """channel down button press."""
-        await self.button(btn.CHANNELDOWN)
-
-    async def play_button(self):
-        """play button press."""
-        await self.button(btn.PLAY)
-
-    async def pause_button(self):
-        """pause button press."""
-        await self.button(btn.PAUSE)
-
-    async def number_button(self, num):
-        """numeric button press."""
-        if not (num >= 0 and num <= 9):
-            raise ValueError
-
-        await self.button(f"""{num}""")
-
     async def luna_request(self, uri, params):
         """luna api call."""
         # n.b. this is a hack which abuses the alert API
@@ -1124,6 +1067,10 @@ class WebOsClient:
 
         return await self.request(ep.CLOSE_ALERT, payload={"alertId": alertId})
 
+    async def input_button(self):
+        """Input button."""
+        return await self.luna_request(ep.LUNA_SHOW_INPUT_PICKER, {})
+
     async def set_current_picture_mode(self, pic_mode):
         """Set picture mode for current input, dynamic range and 3d mode.
 
